#include "RSGGobi.h"

#include <gtk/gtk.h>

#include "vars.h"

#include "R.h"
#include "Rinternals.h"


USER_OBJECT_
RS_GGOBI(setBrushSize)(USER_OBJECT_ dims, USER_OBJECT_ datasetId, USER_OBJECT_ ggobiId)
{
  ggobid *gg;
  datad *d;
  gint wd, ht;
  USER_OBJECT_ ans;

  d = resolveDatad(datasetId, ggobiId, &gg);

  if(d) {  

     GGOBI(getBrushSize(&wd, &ht, gg));
        /* We skip the setting if these values are both -1.
           Allows us to set or get with one function.
         */
     if(INTEGER_DATA(dims)[0] > -1 && INTEGER_DATA(dims)[1] > -1)
       GGOBI(setBrushSize(INTEGER_DATA(dims)[0], INTEGER_DATA(dims)[1], gg));
    
     ans = NEW_INTEGER(2);
     INTEGER_DATA(ans)[0] = wd;
     INTEGER_DATA(ans)[1] = ht;

   /* experiments */
   brush_reset(gg,RESET_UNSHADOW_POINTS);
   /*   displays_plot (NULL, FULL, gg); */
     gdk_flush();
  } else
    ans = NULL_USER_OBJECT;

  return(ans);
}

USER_OBJECT_
RS_GGOBI(setBrushLocation)(USER_OBJECT_ loc, USER_OBJECT_ datasetId, USER_OBJECT_ ggobiId)
{
  ggobid *gg;
  datad *d;
  USER_OBJECT_ ans;
  d = resolveDatad(datasetId, ggobiId, &gg);

  if(d) {
   gint xx, yy;
   GGOBI(getBrushLocation (&xx, &yy, gg));
   if(INTEGER_DATA(loc)[0] > -1 && INTEGER_DATA(loc)[1] > -1)
     GGOBI(setBrushLocation(INTEGER_DATA(loc)[0], INTEGER_DATA(loc)[1], gg));

   ans = NEW_INTEGER(2);  
   INTEGER_DATA(ans)[0] = xx;
   INTEGER_DATA(ans)[1] = yy;
   gdk_flush();
 } else
   ans = NULL_USER_OBJECT;

  return(ans);
}
